==> haskell-monad-logger-0.3.28.5-46-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-monad-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-logger
version: 0.3.28.5
id: monad-logger-0.3.28.5-3xACEIEYeQ5DBxS3ElwWhD
key: monad-logger-0.3.28.5-3xACEIEYeQ5DBxS3ElwWhD
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/snoyberg/monad-logger#readme
synopsis: A class of monads which can log messages.
description:
    See README and Haddocks at <https://www.stackage.org/package/monad-logger>
category: System
abi: 43a94581f6600a0a160b751340ed04ab
exposed: True
exposed-modules:
    Control.Monad.Logger Control.Monad.Logger.CallStack
hidden-modules: Paths_monad_logger
import-dirs: /usr/lib/ghc-8.4.3/site-local/monad-logger-0.3.28.5
library-dirs: /usr/lib/ghc-8.4.3/site-local/monad-logger-0.3.28.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/monad-logger-0.3.28.5
hs-libraries: HSmonad-logger-0.3.28.5-3xACEIEYeQ5DBxS3ElwWhD
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    conduit-1.3.0.3-DaDndYTG6fcCpmR0FtgGkV
    conduit-extra-1.3.0-I63TK4K0usX7XV4suuqdan
    exceptions-0.10.0-7epDYg20HTz9YX9m9nzGfO
    fast-logger-2.4.11-6LKqhJmZGwUIa706cRTW3e
    lifted-base-0.2.3.12-BrYri3LWM9pJ2tWeaR9lDb
    monad-control-1.0.2.3-87lWNcomfXpJ29QmdQvcek
    monad-loops-0.4.3-2NGNwTmuzQ8HUga17olMGs mtl-2.2.2
    resourcet-1.2.1-9sz7rlxvCfi1vnYYgzfo9y stm-2.4.5.0
    stm-chans-3.0.0.4-1zxsnYr1r3u2n2uZuqSuqq text-1.2.3.0
    transformers-0.5.5.0
    transformers-base-0.4.5.2-5KLI3HqoCj57dxyS8p0jMZ
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
    unliftio-core-0.1.1.0-LMRC2BJekXQHTjQ89kypYp
    template-haskell-2.13.0.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             conduit-1.3.0.3-DaDndYTG6fcCpmR0FtgGkV=fd915ceae5687f6d9d6198682cb93cb3
             conduit-extra-1.3.0-I63TK4K0usX7XV4suuqdan=809dac92a00089fb09a5f62a0ecea3ec
             exceptions-0.10.0-7epDYg20HTz9YX9m9nzGfO=87ba3c1011ac70bcfb17ce2e39a2e1bb
             fast-logger-2.4.11-6LKqhJmZGwUIa706cRTW3e=74f385e9dd50fadd4b5101789b2372bf
             lifted-base-0.2.3.12-BrYri3LWM9pJ2tWeaR9lDb=d644bc8a6ccaa6c52fce0344d0467249
             monad-control-1.0.2.3-87lWNcomfXpJ29QmdQvcek=4701eb7c70a10f72aec80f45872b6148
             monad-loops-0.4.3-2NGNwTmuzQ8HUga17olMGs=8f6673eb67ce392bdddb2c5970e7d454
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             resourcet-1.2.1-9sz7rlxvCfi1vnYYgzfo9y=09f9b32ede067fc2006d1c6f61df54b1
             stm-2.4.5.0=cd8ccc9f17cf51980f6d59f12e77db7d
             stm-chans-3.0.0.4-1zxsnYr1r3u2n2uZuqSuqq=95b0b718bbd953252bfb86d62efe20ac
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             transformers-base-0.4.5.2-5KLI3HqoCj57dxyS8p0jMZ=ff843a556414f5766b414ccfa8c6dff6
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=197a030c492741542d6f49bc76370bb8
             unliftio-core-0.1.1.0-LMRC2BJekXQHTjQ89kypYp=900e31672c80ab97985a6f7a2b7fa053
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
haddock-interfaces: /usr/share/doc/haskell-monad-logger/html/monad-logger.haddock
haddock-html: /usr/share/doc/haskell-monad-logger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-logger-0.3.28.5-47-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-monad-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-logger
version: 0.3.28.5
id: monad-logger-0.3.28.5-JNfmspGcORAEkXtJKpnqjY
key: monad-logger-0.3.28.5-JNfmspGcORAEkXtJKpnqjY
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/snoyberg/monad-logger#readme
synopsis: A class of monads which can log messages.
description:
    See README and Haddocks at <https://www.stackage.org/package/monad-logger>
category: System
abi: 4ad83bdb04be8c3a18f8cf2de2f50745
exposed: True
exposed-modules:
    Control.Monad.Logger Control.Monad.Logger.CallStack
hidden-modules: Paths_monad_logger
import-dirs: /usr/lib/ghc-8.4.3/site-local/monad-logger-0.3.28.5
library-dirs: /usr/lib/ghc-8.4.3/site-local/monad-logger-0.3.28.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/monad-logger-0.3.28.5
hs-libraries: HSmonad-logger-0.3.28.5-JNfmspGcORAEkXtJKpnqjY
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    conduit-1.3.0.3-CWvgMypgTVyHtfYib3PvqC
    conduit-extra-1.3.0-7ufd70jXcYy3R0BejWlzSF
    exceptions-0.10.0-7epDYg20HTz9YX9m9nzGfO
    fast-logger-2.4.11-6LKqhJmZGwUIa706cRTW3e
    lifted-base-0.2.3.12-Ffs2vZzT0zj4cBX6I52qqO
    monad-control-1.0.2.3-KD4Vsg6Ia0X5RLt8TMMDV6
    monad-loops-0.4.3-2NGNwTmuzQ8HUga17olMGs mtl-2.2.2
    resourcet-1.2.1-HVkgWTomxbW9sgOb2d5u9e stm-2.4.5.0
    stm-chans-3.0.0.4-1zxsnYr1r3u2n2uZuqSuqq text-1.2.3.0
    transformers-0.5.5.0
    transformers-base-0.4.5.2-CJkbYH4N4LV8hMEohn0j3d
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
    unliftio-core-0.1.1.0-LMRC2BJekXQHTjQ89kypYp
    template-haskell-2.13.0.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             conduit-1.3.0.3-CWvgMypgTVyHtfYib3PvqC=51cc6289d249cec67f7829e2212f3c47
             conduit-extra-1.3.0-7ufd70jXcYy3R0BejWlzSF=3c0c7b09623ef7e64024d5421c7d89c9
             exceptions-0.10.0-7epDYg20HTz9YX9m9nzGfO=87ba3c1011ac70bcfb17ce2e39a2e1bb
             fast-logger-2.4.11-6LKqhJmZGwUIa706cRTW3e=74f385e9dd50fadd4b5101789b2372bf
             lifted-base-0.2.3.12-Ffs2vZzT0zj4cBX6I52qqO=2b5ada4e472e99642c35d08f282210df
             monad-control-1.0.2.3-KD4Vsg6Ia0X5RLt8TMMDV6=c021194f497af7f0c1d884cb305008e2
             monad-loops-0.4.3-2NGNwTmuzQ8HUga17olMGs=8f6673eb67ce392bdddb2c5970e7d454
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             resourcet-1.2.1-HVkgWTomxbW9sgOb2d5u9e=08678aec30adcdae19c0b70973ad5f17
             stm-2.4.5.0=cd8ccc9f17cf51980f6d59f12e77db7d
             stm-chans-3.0.0.4-1zxsnYr1r3u2n2uZuqSuqq=95b0b718bbd953252bfb86d62efe20ac
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             transformers-base-0.4.5.2-CJkbYH4N4LV8hMEohn0j3d=85e83aa98f31119a75b463e70412c07f
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=197a030c492741542d6f49bc76370bb8
             unliftio-core-0.1.1.0-LMRC2BJekXQHTjQ89kypYp=900e31672c80ab97985a6f7a2b7fa053
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
haddock-interfaces: /usr/share/doc/haskell-monad-logger/html/monad-logger.haddock
haddock-html: /usr/share/doc/haskell-monad-logger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
